@@ -95,7 +95,7 @@ class BaseDataSource(AbstractDataSource):
         self._instruments.extend(instruments_store.get_all_instruments())
 
     def register_dividend_store(self, instrument_type, dividend_store):
-        # type: (INSTRUMENT_TYPE, DividendStore) -> None
+        # type: (INSTRUMENT_TYPE, AbstractDividendStore) -> None
         self._dividends[instrument_type] = dividend_store
 
     def register_split_store(self, instrument_type, split_store):
@@ -140,7 +140,8 @@ class BaseDataSource(AbstractDataSource):
             return [False] * len(dates)
 
     def is_st_stock(self, order_book_id, dates):
-        return self._st_stock_days.contains(order_book_id, dates)
+        result = self._st_stock_days.contains(order_book_id, dates)
+        return result if result is not None else [False] * len(dates)
 
     @lru_cache(None)
     def _all_day_bars_of(self, instrument):
