@@ -27,7 +27,7 @@ from rqalpha.environment import Environment
 from rqalpha.const import DAYS_CNT, DEFAULT_ACCOUNT_TYPE, POSITION_DIRECTION
 from rqalpha.utils import merge_dicts
 from rqalpha.utils.repr import PropertyReprMeta
-from rqalpha.events import EVENT
+from rqalpha.core.events import EVENT
 from rqalpha.model.order import OrderStyle, Order
 from rqalpha.interface import AbstractPosition
 
