@@ -16,7 +16,6 @@ from __future__ import division
 import pprint
 import os
 import re
-import six
 import collections
 from decimal import getcontext, ROUND_FLOOR
 from datetime import time
@@ -32,7 +31,7 @@ from rqalpha.const import (
 )
 from rqalpha.utils.datetime_func import TimeRange
 from rqalpha.utils.i18n import gettext as _
-from rqalpha.utils.py2 import lru_cache
+from rqalpha.utils.functools import lru_cache
 
 
 class RqAttrDict(object):
@@ -40,7 +39,7 @@ class RqAttrDict(object):
     def __init__(self, d=None):
         self.__dict__ = d if d is not None else dict()
 
-        for k, v in list(six.iteritems(self.__dict__)):
+        for k, v in list(self.__dict__.items()):
             if isinstance(v, dict):
                 self.__dict__[k] = RqAttrDict(v)
 
@@ -54,7 +53,7 @@ class RqAttrDict(object):
         RqAttrDict._update_dict_recursive(self, other)
 
     def items(self):
-        return six.iteritems(self.__dict__)
+        return self.__dict__.items()
 
     iteritems = items
 
@@ -67,7 +66,7 @@ class RqAttrDict(object):
             other = other.__dict__
         target_dict = target.__dict__ if isinstance(target, RqAttrDict) else target
 
-        for k, v in six.iteritems(other):
+        for k, v in other.items():
             if isinstance(v, RqAttrDict):
                 v = v.__dict__
             if isinstance(v, collections.Mapping):
@@ -79,7 +78,7 @@ class RqAttrDict(object):
 
     def convert_to_dict(self):
         result_dict = {}
-        for k, v in list(six.iteritems(self.__dict__)):
+        for k, v in list(self.__dict__.items()):
             if isinstance(v, RqAttrDict):
                 v = v.convert_to_dict()
             result_dict[k] = v
@@ -142,9 +141,6 @@ INST_TYPE_IN_STOCK_ACCOUNT = [
     INSTRUMENT_TYPE.ETF,
     INSTRUMENT_TYPE.LOF,
     INSTRUMENT_TYPE.INDX,
-    INSTRUMENT_TYPE.FENJI_MU,
-    INSTRUMENT_TYPE.FENJI_A,
-    INSTRUMENT_TYPE.FENJI_B,
     INSTRUMENT_TYPE.PUBLIC_FUND
 ]
 
