@@ -17,6 +17,7 @@
 
 from datetime import date
 
+from numpy.testing import assert_equal, assert_almost_equal
 from rqalpha.apis import *
 
 
@@ -120,3 +121,32 @@ def test_stock_transform():
             assert context.portfolio.cash == context.cash_before_transform
 
     return locals()
+
+
+def test_stock_split():
+    __config__ = {
+        "base": {
+            "start_date": "2016-05-26",
+            "end_date": "2016-05-27"
+        }
+    }
+
+    def init(context):
+        context.s = "000035.XSHE"
+        context.counter = 0
+        context.cash_before_split = None
+
+    def handle_bar(context, bar_dict):
+        context.counter += 1
+        if context.counter == 1:
+            order_shares(context.s, 1000)
+            assert_equal(get_position(context.s, POSITION_DIRECTION.LONG).quantity, 1000)
+            context.cash_before_split = context.portfolio.cash
+        elif context.counter == 2:
+            position = get_position(context.s, POSITION_DIRECTION.LONG)
+            assert_equal(position.quantity, 2000)
+            assert_equal(position.trading_pnl, 0)
+            assert_almost_equal(position.position_pnl, -140)
+            assert_equal(context.portfolio.cash, context.cash_before_split)
+
+    return locals()
